<?php

// ------------ add a meta-box for selecting the post-color ------------ //

add_action( 'add_meta_boxes', 'og_meta_box_add' );

$options = get_option( 'og_theme_options' );

function og_meta_box_add()
{
	add_meta_box( 'my-meta-box-id', __('Choose the post-color','og-achtzehn'), 'og_meta_box_cb', 'post', 'normal', 'high' );
}

function og_meta_box_cb( $post )
{
	$values = get_post_custom( $post->ID );
	$selected = isset( $values['postcolor_meta_box_select'] ) ? esc_attr( $values['postcolor_meta_box_select'][0] ) : '';
	wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
	?>
	<p>
		<select name="postcolor_meta_box_select" id="postcolor_meta_box_select">
			<option value="standard" <?php selected( $selected, '' ); ?>><?php _e('default color','og-achtzehn') ?></option>
			<option value="color1" <?php selected( $selected, 'color1' ); ?>>
				<?php $options = get_option( 'og_theme_options' );
					if ($options['color1_name']) { 
						echo $options['color1_name'];
				} else { 
					echo __('Color 1','og-achtzehn');
				} ?>
			</option>
			<option value="color2" <?php selected( $selected, 'color2' ); ?>>
				<?php $options = get_option( 'og_theme_options' );
					if ($options['color2_name']) { 
						echo $options['color2_name'];
				} else { 
					echo __('Color 2','og-achtzehn');
				} ?>
			</option>
			<option value="color3" <?php selected( $selected, 'color3' ); ?>>
				<?php $options = get_option( 'og_theme_options' );
					if ($options['color3_name']) { 
						echo $options['color3_name'];
				} else { 
					echo __('Color 3','og-achtzehn');
				} ?>
			</option>
			<option value="color4" <?php selected( $selected, 'color4' ); ?>>
				<?php $options = get_option( 'og_theme_options' );
					if ($options['color4_name']) { 
						echo $options['color4_name'];
				} else { 
					echo __('Color 4','og-achtzehn');
				} ?>
			</option>
			<option value="color5" <?php selected( $selected, 'color5' ); ?>>
				<?php $options = get_option( 'og_theme_options' );
					if ($options['color5_name']) { 
						echo $options['color5_name'];
				} else { 
					echo __('Color 5','og-achtzehn');
				} ?>
			</option>
		</select>
	</p>

	<p><?php _e( 'Preselect the post-colors in the <a href="/wp-admin/customize.php">theme-customizing</a>', 'og-achtzehn' ); ?></p>

	<?php	
}

add_action( 'save_post', 'og_meta_box_save' );
function og_meta_box_save( $post_id )
{
	// Bail if we're doing an auto save
	if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
	
	// if our nonce isn't there, or we can't verify it, bail
	if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ) return;
	
	// if our current user can't edit this post, bail
	if( !current_user_can( 'edit_post' ) ) return;
	
	// now we can actually save the data
	$allowed = array( 
		'a' => array( // on allow a tags
			'href' => array() // and those anchords can only have href attribute
		)
	);
	
	// Probably a good idea to make sure your data is set
		
	if( isset( $_POST['postcolor_meta_box_select'] ) )
		update_post_meta( $post_id, 'postcolor_meta_box_select', esc_attr( $_POST['postcolor_meta_box_select'] ) );
		
}



// ------------ load the textdomain for language-support ------------ //

load_theme_textdomain( 'og-achtzehn', get_template_directory() . '/languages');



// ------------ redirecting a search when there is only one result ------------ //

function theme_show_on_match() {  

    if ( is_search() ) {  
        global $wp_query;  
        if ($wp_query->post_count == 1) {  
            wp_redirect( get_permalink( $wp_query->posts['0']->ID ) );  
        }  
    }  
}

add_action('template_redirect', 'theme_show_on_match');  



// ------------ add theme-customizer-options ------------ //

function og_theme_customizer( $wp_customize ) {



// ------------ add section for blog-description ------------ //

	$wp_customize->add_section( 'ACHTZEHN_blog-description', array(
		'title' => __('ACHTZEHN - Blog-description','og-achtzehn'),
		'description' => __('Use the following options to describe you or your blog with a few words. This description will shown in the footer.','og-achtzehn'),
		'priority' => '2'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[blog_description]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[blog_description]', array(
			'label' => __('Display the blog-description','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ACHTZEHN_blog-description',
		) );

		$wp_customize->add_setting( 'og_theme_options[blog_description_title]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[blog_description_title]', array(
			'label' => __('Heading','og-achtzehn'),
			'type' => 'text',
			'priority' => '2',
			'section' => 'ACHTZEHN_blog-description',
		) );

		$wp_customize->add_setting( 'og_theme_options[blog_description_content]', array(
			'type' => 'option',
		) );
		
		$wp_customize->add_control( new WP_Customize_Textarea_Control( $wp_customize, 'og_theme_options[blog_description_content]', array(
			'label'	=> __( 'Description (you can use HTML-Tags)', 'og-achtzehn' ),
			'priority' => '3',
			'section' => 'ACHTZEHN_blog-description',
		) ) );

		$wp_customize->add_setting( 'og_theme_options[blog_description_logo]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'og_theme_options[blog_description_logo]', array(
			'label'   => __('Upload a logo to show inside the blog-description','og-achtzehn'),
			'priority' => '4',
			'section' => 'ACHTZEHN_blog-description',
		) ) );


// ------------ add section for basic options ------------ //

	$wp_customize->add_section( 'ACHTZEHN_basic', array(
		'title' => __('ACHTZEHN - Basic options','og-achtzehn'),
		'priority' => '1'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[font_size]', array(
			'default' => '13px',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[font_size]', array(
			'label' => __('Default font-size','og-achtzehn'),
			'section' => 'ACHTZEHN_basic',
			'type' => 'radio',
			'priority' => '2',
			'choices' => array(
				'14px' => __('14 Pixel','og-achtzehn'),
				'15px' => __('15 Pixel (default)','og-achtzehn'),
				'16px' => __('16 Pixel','og-achtzehn'),
				'17px' => __('17 Pixel','og-achtzehn'),
				'18px' => __('18 Pixel','og-achtzehn'),
			),
		) );

		$wp_customize->add_setting( 'og_theme_options[font_standard]', array(
			'default' => '0',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[font_standard]', array(
			'label' => __('Default font','og-achtzehn'),
			'section' => 'ACHTZEHN_basic',
			'type' => 'select',
			'priority' => '3',
			'choices' => array(
				'0' => __('Muli (default)','og-achtzehn'),
				'1' => 'Open Sans',
				'2' => 'Source Sans Pro',
				'3' => 'PT Sans',
				'4' => 'Ubuntu',
				'5' => 'Roboto',
				'6' => 'Varela Round',
				'7' => 'Noto Serif',
				'8' => 'Arial',
				'9' => 'Verdana',
				'10' => 'Tahoma',
				'11' => 'Lucida Sans',
				'12' => __('Custom','og-achtzehn'),
			),
		) );

		$wp_customize->add_setting( 'og_theme_options[font_standard_html]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[font_standard_html]', array(
			'label' => __('HTML-Code (<link href=...>) for custom default font','og-achtzehn'),
			'type' => 'text',
			'priority' => '4',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[font_standard_css]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[font_standard_css]', array(
			'label' => __('CSS-Code (font-family:...;) for custom default font','og-achtzehn'),
			'type' => 'text',
			'priority' => '5',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[font_h]', array(
			'default' => '0',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[font_h]', array(
			'label' => __('Default heading-font','og-achtzehn'),
			'section' => 'ACHTZEHN_basic',
			'type' => 'select',
			'priority' => '6',
			'choices' => array(
				'0' => __('Bitter (default)','og-achtzehn'),
				'1' => 'Fjalla One',
				'2' => 'Nunito',
				'3' => 'Archivo Narrow',
				'4' => 'Open Sans Condensed',
				'5' => 'Raleway',
				'6' => 'Bree Serif',
				'7' => 'Open Sans light',
				'8' => 'Roboto Condensed',
				'9' => 'Arial',
				'10' => 'Verdana',
				'11' => 'Tahoma',
				'12' => 'Lucida Sans',
				'13' => __('Custom','og-achtzehn'),
			),
		) );

		$wp_customize->add_setting( 'og_theme_options[font_h_html]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[font_h_html]', array(
			'label' => __('HTML-Code (<link href=...>) for custom heading font','og-achtzehn'),
			'type' => 'text',
			'priority' => '7',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[font_h_css]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[font_h_css]', array(
			'label' => __('CSS-Code (font-family:...;) for custom heading font','og-achtzehn'),
			'type' => 'text',
			'priority' => '8',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[posts_comments]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[posts_comments]', array(
			'label' => __('Display number of posts and comments in the theme-credits','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '9',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[copyright]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[copyright]', array(
			'label' => __('Text for copyright','og-achtzehn'),
			'type' => 'text',
			'priority' => '10',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[google_analytics]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( new WP_Customize_Textarea_Control( $wp_customize, 'og_theme_options[google_analytics]', array(
			'label' => __('Paste your Google Analytics code','og-achtzehn'),
			'priority' => '11',
			'section' => 'ACHTZEHN_basic',
		) ) );

		$wp_customize->add_setting( 'og_theme_options[excerpt_words]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[excerpt_words]', array(
			'label' => __('Number of words for excerpts','og-achtzehn'),
			'type' => 'text',
			'priority' => '13',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[excerpt_moretag]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[excerpt_moretag]', array(
			'label' => __('Excerpts with a more-button','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '14',
			'section' => 'ACHTZEHN_basic',
		) );

		$wp_customize->add_setting( 'og_theme_options[infosection_view]', array(
			'default' => '0',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[infosection_view]', array(
			'label' => __('Display the info-section','og-achtzehn'),
			'section' => 'ACHTZEHN_basic',
			'type' => 'select',
			'priority' => '15',
			'choices' => array(
				'0' => __('close and clickable (default)','og-achtzehn'),
				'1' => __('open and not clickable','og-achtzehn'),
			),
		) );
		$wp_customize->add_setting( 'og_theme_options[searchform]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[searchform]', array(
			'label' => __('Display a search-form in the info-section','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '15',
			'section' => 'ACHTZEHN_basic',
		) );



// ------------ add a section for logo upload ------------ //

	$wp_customize->add_section( 'ACHTZEHN_logo', array(
		'title' => __('ACHTZEHN - Logo','og-achtzehn'),
		'priority' => '3'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[display_logo_header]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[display_logo_header]', array(
			'label' => __('Display a logo in the header','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ACHTZEHN_logo',
		) );

		$wp_customize->add_setting( 'og_theme_options[logo_header]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'og_theme_options[logo_header]', array(
			'label'   => __('Upload your own logo','og-achtzehn'),
			'priority' => '2',
			'section' => 'ACHTZEHN_logo',
		) ) );

		$wp_customize->add_setting( 'og_theme_options[display_logo_footer]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[display_logo_footer]', array(
			'label' => __('Display a logo in the footer','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ACHTZEHN_logo',
		) );

		$wp_customize->add_setting( 'og_theme_options[logo_footer]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'og_theme_options[logo_footer]', array(
			'label'   => __('Upload your own logo','og-achtzehn'),
			'priority' => '4',
			'section' => 'ACHTZEHN_logo',
		) ) );


// ------------ add a section for post options ------------ //

	$wp_customize->add_section( 'ACHTZEHN_posts', array(
		'title' => __('ACHTZEHN - Post options','og-achtzehn'),
		'priority' => '3'
	) );

	// add the settings and the controls
			
		$wp_customize->add_setting( 'og_theme_options[post_view]', array(
			'default' => '0',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_view]', array(
			'label' => __('Display the post-content on Blog-pages as','og-achtzehn'),
			'section' => 'ACHTZEHN_posts',
			'type' => 'select',
			'priority' => '1',
			'choices' => array(
				'0' => __('content (default)','og-achtzehn'),
				'1' => __('excerpt','og-achtzehn'),
			),
		) );

		$wp_customize->add_setting( 'og_theme_options[post_thumbnail]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_thumbnail]', array(
			'label' => __('Display the featured-thumbnail on blog-pages','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_author]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_author]', array(
			'label' => __('Display an author-box','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_info_author]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_info_author]', array(
			'label' => __('Display name of post-author in the post-informations','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '4',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_navigation_top]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_navigation_top]', array(
			'label' => __('Display post-navigation in the head-section','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '5',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_navigation_bottom]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_navigation_bottom]', array(
			'label' => __('Display post-navigation beyond the post','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '6',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_recommendation]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_recommendation]', array(
			'label' => __('Display post-recommendations','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '7',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_recommendation_title]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[post_recommendation_title]', array(
			'label' => __('Heading for the post-recommendation','og-achtzehn'),
			'type' => 'text',
			'priority' => '8',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_recommendation_nr]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[post_recommendation_nr]', array(
			'label' => __('Number of posts for recommendation','og-achtzehn'),
			'type' => 'text',
			'priority' => '9',
			'section' => 'ACHTZEHN_posts',
		) );

		$wp_customize->add_setting( 'og_theme_options[post_recommendation_type]', array(
			'default' => '0',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[post_recommendation_type]', array(
			'label' => __('Display the post-recommendations as','og-achtzehn'),
			'section' => 'ACHTZEHN_posts',
			'type' => 'radio',
			'priority' => '10',
			'choices' => array(
				'0' => __('excerpt (default)','og-achtzehn'),
				'1' => __('list','og-achtzehn'),
			),
		) );



// ------------ add a section for post-share buttons ------------ //

	$wp_customize->add_section( 'ACHTZEHN_share', array(
		'title' => __('ACHTZEHN - Share buttons','og-achtzehn'),
		'priority' => '4'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[share_google]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[share_google]', array(
			'label' => __('Google+1-button','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ACHTZEHN_share',
		) );

		$wp_customize->add_setting( 'og_theme_options[share_facebook]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[share_facebook]', array(
			'label' => __('Facebook like-button','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ACHTZEHN_share',
		) );

		$wp_customize->add_setting( 'og_theme_options[share_twitter]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[share_twitter]', array(
			'label' => __('Twitter tweet-button','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '4',
			'section' => 'ACHTZEHN_share',
		) );

		$wp_customize->add_setting( 'og_theme_options[share_pinterest]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[share_pinterest]', array(
			'label' => __('Pinterest Pin It-button','og-achtzehn'),
			'type' => 'checkbox',
			'priority' => '5',
			'section' => 'ACHTZEHN_share',
		) );


// ------------ add a section for social network options ------------ //

	$wp_customize->add_section( 'ACHTZEHN_social', array(
		'title' => __('ACHTZEHN - Social Networks','og-achtzehn'),
		'priority' => '5'
	) );

	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[social_title]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[social_title]', array(
			'label' => __('Heading for the Social Networks links','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '1'
		) );

		$wp_customize->add_setting( 'og_theme_options[facebook]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[facebook]', array(
			'label' => 'Facebook',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '1'
		) );

		$wp_customize->add_setting( 'og_theme_options[facebook_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[facebook_url]', array(
			'label' => __('Link to your Facebook profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '2'
		) );

		$wp_customize->add_setting( 'og_theme_options[facebook_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[facebook_tooltip]', array(
			'label' => __('Facebook tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '3'
		) );

		$wp_customize->add_setting( 'og_theme_options[twitter]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[twitter]', array(
			'label' => 'Twitter',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '4'
		) );

		$wp_customize->add_setting( 'og_theme_options[twitter_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[twitter_url]', array(
			'label' => __('Link to your Twitter profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '5'
		) );

		$wp_customize->add_setting( 'og_theme_options[twitter_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[twitter_tooltip]', array(
			'label' => __('Twitter tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '6'
		) );

		$wp_customize->add_setting( 'og_theme_options[google]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[google]', array(
			'label' => 'Google+',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '7'
		) );

		$wp_customize->add_setting( 'og_theme_options[google_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[google_url]', array(
			'label' => __('Link to your Google+ profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '8'
		) );

		$wp_customize->add_setting( 'og_theme_options[google_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[google_tooltip]', array(
			'label' => __('Google+ tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '9'
		) );

		$wp_customize->add_setting( 'og_theme_options[xing]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[xing]', array(
			'label' => 'Xing',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '10'
		) );

		$wp_customize->add_setting( 'og_theme_options[xing_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[xing_url]', array(
			'label' => __('Link to your Xing profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '11'
		) );

		$wp_customize->add_setting( 'og_theme_options[xing_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[xing_tooltip]', array(
			'label' => __('Xing tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '12'
		) );

		$wp_customize->add_setting( 'og_theme_options[pinterest]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[pinterest]', array(
			'label' => 'Pinterest',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '13'
		) );

		$wp_customize->add_setting( 'og_theme_options[pinterest_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[pinterest_url]', array(
			'label' => __('Link to your Pinterest profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '14'
		) );

		$wp_customize->add_setting( 'og_theme_options[pinterest_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[pinterest_tooltip]', array(
			'label' => __('Pinterest tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '15'
		) );

		$wp_customize->add_setting( 'og_theme_options[tumblr]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[tumblr]', array(
			'label' => 'Tumblr',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '16'
		) );

		$wp_customize->add_setting( 'og_theme_options[tumblr_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[tumblr_url]', array(
			'label' => __('Link to your Tumblr profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '17'
		) );

		$wp_customize->add_setting( 'og_theme_options[tumblr_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[tumblr_tooltip]', array(
			'label' => __('Tumblr tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '18'
		) );

		$wp_customize->add_setting( 'og_theme_options[linkedin]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[linkedin]', array(
			'label' => 'Linkedin',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '19'
		) );

		$wp_customize->add_setting( 'og_theme_options[linkedin_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[linkedin_url]', array(
			'label' => __('Link to your Linkedin profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '20'
		) );

		$wp_customize->add_setting( 'og_theme_options[linkedin_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[linkedin_tooltip]', array(
			'label' => __('Linkedin tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '21'
		) );

		$wp_customize->add_setting( 'og_theme_options[instagram]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[instagram]', array(
			'label' => 'Instagram',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '22'
		) );

		$wp_customize->add_setting( 'og_theme_options[instagram_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[instagram_url]', array(
			'label' => __('Link to your Instagram profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '23'
		) );

		$wp_customize->add_setting( 'og_theme_options[instagram_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[instagram_tooltip]', array(
			'label' => __('Instagram tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '24'
		) );

		$wp_customize->add_setting( 'og_theme_options[flickr]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[flickr]', array(
			'label' => 'Flickr',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '25'
		) );

		$wp_customize->add_setting( 'og_theme_options[flickr_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[flickr_url]', array(
			'label' => __('Link to your Flickr profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '26'
		) );

		$wp_customize->add_setting( 'og_theme_options[flickr_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[flickr_tooltip]', array(
			'label' => __('Flickr tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '27'
		) );

		$wp_customize->add_setting( 'og_theme_options[lastfm]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[lastfm]', array(
			'label' => 'Last.fm',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '28'
		) );

		$wp_customize->add_setting( 'og_theme_options[lastfm_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[lastfm_url]', array(
			'label' => __('Link to your Last.fm profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '29'
		) );

		$wp_customize->add_setting( 'og_theme_options[lastfm_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[lastfm_tooltip]', array(
			'label' => __('Last.fm tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '30'
		) );

		$wp_customize->add_setting( 'og_theme_options[youtube]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[youtube]', array(
			'label' => 'YouTube',
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '31'
		) );

		$wp_customize->add_setting( 'og_theme_options[youtube_url]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[youtube_url]', array(
			'label' => __('Link to your YouTube profile','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '32'
		) );

		$wp_customize->add_setting( 'og_theme_options[youtube_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[youtube_tooltip]', array(
			'label' => __('YouTube tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '33'
		) );

		$wp_customize->add_setting( 'og_theme_options[rss]', array(
			'default' => 0,
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'og_theme_options[rss]', array(
			'label' => __('RSS-Feed','og-achtzehn'),
			'type' => 'checkbox',
			'section' => 'ACHTZEHN_social',
			'priority' => '34'
		) );

		$wp_customize->add_setting( 'og_theme_options[rss_tooltip]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[rss_tooltip]', array(
			'label' => __('RSS-Feed tooltip-text','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_social',
			'priority' => '35'
		) );



// ------------ add settings and controls for post-colors ------------ //

	$wp_customize->add_section( 'ACHTZEHN_post-colors', array(
		'title' => __('ACHTZEHN - Post colors','og-achtzehn'),
		'description' => __('You can assign a special background-color for every post in the post-editor. With the following options you can preselect five colors you will use','og-achtzehn'),
		'priority' => '6'
	) );

	// add the settings and the controls

		$wp_customize->add_setting( 'og_theme_options[color1]', array(
			'default' => '#fff',
			'type' => 'option',
			'sanitize_callback'    => 'sanitize_hex_color_no_hash',
			'sanitize_js_callback' => 'maybe_hash_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[color1]', array(
			'label'   => __('Post color 1','og-achtzehn'),
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '1'
		) ) );

		$wp_customize->add_setting( 'og_theme_options[color1_name]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[color1_name]', array(
			'label' => __('Name for post color 1','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '2'
		) );

		$wp_customize->add_setting( 'og_theme_options[color2]', array(
			'default' => '#fff',
			'type' => 'option',
			'sanitize_callback'    => 'sanitize_hex_color_no_hash',
			'sanitize_js_callback' => 'maybe_hash_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[color2]', array(
			'label'   => __('Post color 2','og-achtzehn'),
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '3'
		) ) );

		$wp_customize->add_setting( 'og_theme_options[color2_name]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[color2_name]', array(
			'label' => __('Name for post color 2','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '4'
		) );

		$wp_customize->add_setting( 'og_theme_options[color3]', array(
			'default' => '#fff',
			'type' => 'option',
			'sanitize_callback'    => 'sanitize_hex_color_no_hash',
			'sanitize_js_callback' => 'maybe_hash_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[color3]', array(
			'label'   => __('Post color 3','og-achtzehn'),
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '5'
		) ) );

		$wp_customize->add_setting( 'og_theme_options[color3_name]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[color3_name]', array(
			'label' => __('Name for post color 3','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '6'
		) );

		$wp_customize->add_setting( 'og_theme_options[color4]', array(
			'default' => '#fff',
			'type' => 'option',
			'sanitize_callback'    => 'sanitize_hex_color_no_hash',
			'sanitize_js_callback' => 'maybe_hash_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[color4]', array(
			'label'   => __('Post color 4','og-achtzehn'),
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '7'
		) ) );

		$wp_customize->add_setting( 'og_theme_options[color4_name]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[color4_name]', array(
			'label' => __('Name for post color 4','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '8'
		) );

		$wp_customize->add_setting( 'og_theme_options[color5]', array(
			'default' => '#fff',
			'type' => 'option',
			'sanitize_callback'    => 'sanitize_hex_color_no_hash',
			'sanitize_js_callback' => 'maybe_hash_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[color5]', array(
			'label'   => __('Post color 5','og-achtzehn'),
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '9'
		) ) );

		$wp_customize->add_setting( 'og_theme_options[color5_name]', array(
			'type' => 'option',
		) );

		$wp_customize->add_control( 'og_theme_options[color5_name]', array(
			'label' => __('Name for post color 5','og-achtzehn'),
			'type' => 'text',
			'section' => 'ACHTZEHN_post-colors',
			'priority' => '10'
		) );



// ------------ add settings and controls for theme-colors ------------ //

	$wp_customize->add_setting( 'og_theme_options[default_color]', array(
		'default' => '#c92828',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[default_color]', array(
		'label'   => __('Default color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '1'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[akzent_color]', array(
		'default' => '#317752',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[akzent_color]', array(
		'label'   => __('Akzent color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '2'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[alternate_color]', array(
		'default' => '#a2af92',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[alternate_color]', array(
		'label'   => __('Alternate color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '3'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[contrast_color]', array(
		'default' => '#f0f0f0',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[contrast_color]', array(
		'label'   => __('Contrast color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '4'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[sidebar_color]', array(
		'default' => '#444444',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[sidebar_color]', array(
		'label'   => __('Information section color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '5'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[footer_color]', array(
		'default' => '#303030',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[footer_color]', array(
		'label'   => __('Footer color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '6'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[default_font_color]', array(
		'default' => '#222222',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[default_font_color]', array(
		'label'   => __('Font color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '7'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[link_color]', array(
		'default' => '#839a62',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[link_color]', array(
		'label'   => __('Hyperlink color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '8'
	) ) );

	$wp_customize->add_setting( 'og_theme_options[hover_color]', array(
		'default' => '#768c71',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'og_theme_options[hover_color]', array(
		'label'   => __('Hover color','og-achtzehn'),
		'section' => 'colors',
		'priority' => '9'
	) ) );



// ------------ add settings and controls for title and tagline ------------ //

	$wp_customize->add_setting( 'og_theme_options[bloginfo]', array(
		'default' => '0',
		'type' => 'option',
	) );
	 
	$wp_customize->add_control( 'og_theme_options[bloginfo]', array(
		'label' => __('Display title and/or tagline','og-achtzehn'),
		'section' => 'title_tagline',
		'type' => 'select',
		'choices' => array(
			'0' => __('none','og-achtzehn'),
			'1' => __('Site Title','og-achtzehn'),
			'2' => __('Tagline','og-achtzehn'),
			'3' => __('Site Title and Tagline','og-achtzehn'),
		),
	) );

}

add_action( 'customize_register', 'og_theme_customizer', 11 );



// ------------ add a textarea-control for theme-customizing ------------ //

if( class_exists( 'WP_Customize_Control' ) ):
	class WP_Customize_Textarea_Control extends WP_Customize_Control {
		public $type = 'textarea';
 
		public function render_content() {
			?>
		<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="10" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
		</label>
		<?php
		}
	}
endif;



// ------------ add a theme-based stylesheet for TinyMCE ------------ //

add_editor_style();



// ------------ activate the custom-background-function and set the default background ------------ //

$args = array(
	'default-color' => '555555',
);

add_theme_support( 'custom-background', $args );



//------------- activate the custom-header-function and set the default header-image -------------//

$defaults = array(
	'random-default'         => false,
	'width'                  => 0,
	'height'                 => 0,
	'flex-height'            => true,
	'flex-width'             => true,
	'header-text'            => false,
	'uploads'                => true,
);

add_theme_support( 'custom-header', $defaults );



// ------------ activate the post-thumbnail-function and set the sizes ------------ //

if ( function_exists('add_theme_support') ) {
add_theme_support( 'post-thumbnails', array('post') );

	set_post_thumbnail_size(1400, 300, true);
	add_image_size( 'featured-thumbnail', 300, 150, true ); 
}



// ------------ show post-thumbnails in the list of posts in the backend if function is enabled ------------ //

if ( !function_exists('fb_AddThumbColumn') && function_exists('add_theme_support') ) {
add_theme_support('post-thumbnails', array( 'post', 'page' ) );

	function fb_AddThumbColumn($cols) {
       		$cols['thumbnail'] = ('Thumbnail');
	        return $cols;
	}

	function fb_AddThumbValue($column_name, $post_id) {

	            $width = (int) 35;
        	    $height = (int) 35;

	            if ( 'thumbnail' == $column_name ) {
        	        // thumbnail of WP 2.9
                	$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
	                // image from gallery
        	        $attachments = get_children( array('post_parent' => $post_id, 'post_type' => 'attachment', 'post_mime_type' => 'image') );
                	if ($thumbnail_id)
	                    $thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
        	        elseif ($attachments) {
                	    foreach ( $attachments as $attachment_id => $attachment ) {
                        	$thumb = wp_get_attachment_image( $attachment_id, array($width, $height), true );
	                    }
        	        }
                	    if ( isset($thumb) && $thumb ) {
                        	echo $thumb;
	                    } else {
        	                echo ('None');
                	    }
	            }
   	}

	    add_filter( 'manage_posts_columns', 'fb_AddThumbColumn' );
	    add_action( 'manage_posts_custom_column', 'fb_AddThumbValue', 10, 2 );
}


				
// ------------ register the sidebars ------------ //

if ( function_exists('register_sidebar') )
register_sidebar( array(
	'name' => 'Footer Widgets left',
	'id' => 'footer-widgets-left',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

if ( function_exists('register_sidebar') )
register_sidebar( array(
	'name' => 'Footer Widgets middle',
	'id' => 'footer-widgets-middle',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

if ( function_exists('register_sidebar') )
register_sidebar( array(
	'name' => 'Footer Widgets right',
	'id' => 'footer-widgets-right',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);



// ------------ register the nav-menus ------------ //

if ( function_exists('register_nav_menus') ) {
register_nav_menus( array(
	'top_menu' => __( 'Top-main-navigation','og-achtzehn' ),
	'footer_menu' => __( 'Footer-navigation (only 1st level)','og-achtzehn' )
	)
);
}



// ------------ activate feed-link-support ------------ //

if ( function_exists('add_theme_support') ) {
add_theme_support('automatic-feed-links');
}



// ------------ set the maximum content width ------------ //

if ( ! isset( $content_width ) ) $content_width = 800;



// ------------ set the number of words for the post-excerpt ------------ //

function custom_excerpt_length( $length ) {

$options = get_option( 'og_theme_options' );

	if ($options['excerpt_words']) { 
		return $options['excerpt_words'];
	} else { 
		return 55;
	}
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

 

// ------------ show a read-more-link for the excerpt ------------ //

$options = get_option( 'og_theme_options' );

if ($options['excerpt_moretag'] == 1) {

function new_excerpt_more($more) {
        return '
		<p><a class="more-link" href="'.get_permalink().'">' . __('Continue reading','og-achtzehn') . '</a></p>';
}
add_filter('excerpt_more', 'new_excerpt_more');

}



// ------------ shorten the post-title for the newsticker ------------ //

function short_title($after = '', $length) {
	$mytitle = explode(' ', get_the_title(), $length);
	if (count($mytitle)>=$length) {
		array_pop($mytitle);
		$mytitle = implode(" ",$mytitle). $after;
	} else {
		$mytitle = implode(" ",$mytitle);
	}
	return $mytitle;
}



// ------------ set shortcodes for columns ------------ //

function twocolumns_shortcode( $atts, $content = null ) {
	return '<div class="two-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'two-columns', 'twocolumns_shortcode' );

function threecolumns_shortcode( $atts, $content = null ) {
	return '<div class="three-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'three-columns', 'threecolumns_shortcode' );



// ------------ set shortcodes for infoboxes ------------ //

function infobox_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
      'color' => '', 
	   ), $atts ) );
      return '<div class="infobox ' . $color . '">' . do_shortcode($content) . '</div>';

}
add_shortcode('infobox', 'infobox_shortcode');



// ------------ set shortcodes for buttons ------------ //

function button_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
	'color' => '', 
	'size' => '', 
	'link' => '',
	'align' => '',
	), $atts ) );
	return '<a href="' . $link . '" class="button ' . $size . ' ' . $align . ' ' . $color . '">' . $content . '</a>';
}
add_shortcode('button', 'button_shortcode');



// ------------ delete the shortcodes from the excerpt ------------ //

function custom_excerpt($text = '') {
	$raw_excerpt = $text;
	if ( '' == $text ) {
		$text = get_the_content('');
                // $text = strip_shortcodes( $text );
		$text = do_shortcode( $text );
		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]>', $text);
		$excerpt_length = apply_filters('excerpt_length', 55);
		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
	}
	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
}
remove_filter( 'get_the_excerpt', 'wp_trim_excerpt'  );
add_filter( 'get_the_excerpt', 'custom_excerpt'  );

?>